@@ -133,10 +133,10 @@ NULL
 #' Publish package
 #'
 #' This package processes results of descriptive statistcs and regression analysis into final tables and figures of a manuscript
-#' @docType package
+#' @keywords internal
 #' @name Publish-package
 #' @importFrom data.table as.data.table copy data.table is.data.table melt rbindlist setnames setorder setcolorder setkey ":=" ".N" ".SD"
-NULL
+"_PACKAGE"
 
 #' traceR data
 #'
